@@ -29,8 +29,8 @@ def top_keyword_multiprocessing(appid_list, keyword_hot_start, start_time, end_t
     # 创建多个进程，表示可以同时执行的进程数量。默认大小是CPU的核心数
     p = Pool(len(appid_list))
     for appid in appid_list:
-        # 创建进程，放入进程池统一管理
-        p.apply_async(multiprocessing_run, args=(appid, keyword_hot_start, start_time, end_time, file_path, ))
+        # 创建进程，放入进程池统一管理；
+        p.apply_async(multiprocessing_run, args=(appid, keyword_hot_start, start_time, end_time, file_path))
     # 如果我们用的是进程池，在调用join()之前必须要先close()，并且在close()之后不能再继续往进程池添加新的进程
     p.close()
     # 进程池对象调用join，会等待进程吃中所有的子进程结束完毕再去结束父进程
@@ -40,6 +40,7 @@ def multiprocessing_run(appid, keyword_hot_start, start_time, end_time, file_pat
     appname = Get_App_Appinfo(appid).get_subname()
     print("【%s】子进程开始，进程ID：%d\n" % (appname, os.getpid()))
     old_seconds = datetime.datetime.now()
+    print(appid)
     Get_Top_Keyword(appid, keyword_hot_start, start_time, end_time).df_to_excel(file_path)
     now_seconds = datetime.datetime.now()
     interval_seconds =round((now_seconds - old_seconds).seconds/60, 2)
